<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:param name="part"/>
	<xsl:param name="var-token"/>
	<xsl:param name="varGrp-token"/>
	<xsl:variable name="filename">
		<xsl:value-of select="codeBook/docDscr/citation/holdings/@URI"/>
	</xsl:variable>
	<xsl:template match="codeBook">
		<xsl:comment>This XML stylesheet is intended to serve as a generic stylesheet for HTML
            display of codebooks marked up according to Version 2.0 of the DDI DTD. Please note that 
            the part navigation that appears just below the title is dependent upon the 'holdings' tag
            located at /codeBook/docDscr/citation/holdings. This navigation element allows the user
            to selectively view any of the five parts of the DDI document, assuming those parts are
            present. The URI attribute of the 'holdings' tag should contain the URL at which the XML
            file is accessed on the Web. If that field is not filled in properly, the navigation
            will not work correctly.</xsl:comment>
		<xsl:comment>It's also important to note that this stylesheet doesn't display all elements. 
            The following elements do note display:
            3.2.1 dataItem (locMap)
            3.2.1.1 CubeCoord (locMap)
            3.2.1.2 physLoc (locMap)
            4.2.1 labl (nCubeGrp)
            4.2.2 txt (nCubeGrp)
            4.2.3 concept (nCubeGrp)
            4.2.4 defntn (nCubeGrp)
            4.2.5 universe (nCubeGrp)
            4.2.6 notes (nCubeGrp)
            4.3.18.5 mrow (nCube)
            4.3.18.5.1 mi (nCube)
            4.4.2 location (nCube)
            4.4.3 txt (nCube)
            4.4.4 universe (nCube)
            4.4.5 imputation (nCube)
            4.4.6 security (nCube)
            4.4.7 embargo (nCube)
            4.4.8 respUnit (nCube)
            4.4.9 anlysUnit (nCube)
            4.4.10 verStmt (nCube)
            4.4.10.1 version (nCube)
            4.4.10.2 verResp (nCube)
            4.4.10.3 notes (nCube)
            4.4.11 purpose (nCube)
            4.4.12.1 cohort (nCube)
            4.4.12.1.1 range (nCube)
            4.4.13 measure (nCube)
            4.4.14 notes (nCube)
            
            In addition, many of the attributes of elements have yet to be set to display.
            </xsl:comment>
		<html>
			<head>
				<title>
					<xsl:value-of select="stdyDscr/citation/titlStmt/titl"/>
				</title>
				<style type="text/css" media="screen">
body {
background-color: #FFFFFF;
margin-top: 5px;
margin-left: 5px;
margin-right: 5px;
padding-left: 0px;
padding-top: 0px;
padding-right: 0px;
}

tr.h1 {
background: #000000;
color: #FFFFFF;
}

td.h3 {
vertical-align: top;
text-align: right;
font-style: italic;
}

tr.h2 {
background: #CCCCCC;
color: #000000;
}

caption {
font-family: arial, helvetica, geneva, verdana, sans-serif;
font-size: 11pt;
font-weight: bold;
}

p {
font-family: arial, helvetica, geneva, verdana, sans-serif;
font-size: 12pt;
}

table {
padding-top: 10px;
padding-bottom: 10px;
border: none;
}

th {
text-align: left;
}

dl {
font-family: arial, helvetica, geneva, verdana, sans-serif;
font-size: 11pt;
}

td {
vertical-align: top;
}

blockquote {
font-family: arial, helvetica, geneva, verdana, sans-serif;
font-size: 11pt;
}

.noindent {padding-left: 0px;}

.small {font-size: 9pt;}

.red {color: #CC0000;}

ol {
font-family: arial, helvetica, geneva, verdana, sans-serif;
font-size: 11pt;
}

ul {
font-family: arial, helvetica, geneva, verdana, sans-serif;
list-style: square;
font-size: 11pt;
}

h1 {
font-family: arial, helvetica, geneva, verdana, sans-serif; 
font-size: 14pt;
}

h2 {
font-family: arial, helvetica, geneva, verdana, sans-serif; 
font-size: 12pt;
}

h3 {
font-family: arial, helvetica, geneva, verdana, sans-serif; 
font-size: 11pt;
font-style: bold;
}

h4 {
font-family: arial, helvetica, geneva, verdana, sans-serif; 
font-size: 10pt;
}
h0 {
font-family: arial; 
font-size: 18pt;
font-style: bold;
}
				</style>
			</head>
			<body bgcolor="#ffffff" lang="en-US">
			<!-- CORRECTION 1: Add the most important figure to the front page-->
				<img src="sample.jpg" width="625" height="530"/>
				<p>
				<br/><br/>
					<h0 style="font-family:helvetica">
						<font size="+3">
							<b>
								<!-- CORRECTION 2: If you wish to change the title described in the DDI codebook, replace the follwing code with the new title-->
								<xsl:value-of select="stdyDscr/citation/titlStmt/titl"/> <!--(ICPSR <xsl:value-of
                        select="stdyDscr/citation/titlStmt/IDNo"/>)<xsl:if test="stdyDscr/citation/titlStmt/altTitl">
                        <br/>(<xsl:value-of select="stdyDscr/citation/titlStmt/altTitl"/>)</xsl:if>-->
							</b>
						</font>
					</h0>
				</p>
				<p style="font-family:helvetica">
					<font size="5%">
						<b>
							<!-- CORRECTION 3: If you have archived using NESSTAR 1 use:"<xsl:value-of select="docDscr/citation/distStmt/contact"/>
												If the dataset is archived under NESSTAR 2, use: "xsl:value-of-select="docDscr/citation/rspStmt/AuthEnty"/> -->
							<xsl:value-of select="docDscr/citation/distStmt/contact"/>
						</b>
					</font>
				</p>
				<br/>
				<br/>
				<br/>
				<br/>
				<br/><br/><br/>
				<br/><br/><br/><br/><br/><br/><br/><br/>
				<table border="0" cellpadding="5" cellspacing="0"  width="90%">
					<tbody>
						<tr>
							<!-- CORRECTION 4: Name of the series (i.e. Travel Survey Metadata Series) and the serial number of the current dataset. For example- 1, or, 10, or 14 etc.-->							
							<th align="left" style="font-size:12pt"><font style="font-family=helvetica"> Travel Survey Metadata Series</font></th>							
							<th align="right" style="font-size:12pt"><font style="font-family=helvetica">1</font></th>
						</tr>
					</tbody>
				</table>
				<!--<p style="font-size:14"><b>Travel Survey Metadata series</b></p><br/>-->
				<table border="0" cellpadding="5" cellspacing="0">
					<td align="left">
						<img src="ivt.jpg" width="296" height="36"/>
					</td>
					<td align="right">
						<img src="eth.jpg" width="290" height="82"/>
					</td>
				</table>
				
				<table border="0" cellpadding="5" cellspacing="0">
					<tr style="page-break-before:always">
						<td> 
							<!-- CORRECTION 5: Name of the series (i.e. Travel Survey Metadata Series) -->
							<p style="font-size:12pt"><br/><br/> Travel Survey Metadata Series</p>
						</td>
					</tr>
					<tr>
						<th>
							<!-- CORRECTION 2: If you wish to change the title described in the DDI codebook, replace the follwing code with the new title-->
							<p style="font-family:helvetica"><font size="+2"><b><xsl:value-of select="stdyDscr/citation/titlStmt/titl"/></b></font></p>
						</th>
					</tr><tr>
						<td>
							<br/><br/>
							<!-- CORRECTION 3: If you have archived using NESSTAR 1 use:"<xsl:value-of select="docDscr/citation/distStmt/contact"/>
												If the dataset is archived under NESSTAR 2, use: "xsl:value-of-select="docDscr/citation/rspStmt/AuthEnty"/> -->

							<p style="font-size:12pt">
							<!-- CORRECTION 6: Contact person(s) address(es) -->
								<xsl:value-of select="docDscr/citation/distStmt/contact"/><br/>
								IVT<br/>
								ETH Zürich<br/>
								Zürich
							</p>
						</td>
						<td/>
					</tr>
					<tr>
						<td>
						<br/><br/>
						<p style="font-size:12pt">
							Phone:		01-633 33 40<br/>
							Fax:		01-633 10 57<br/>
							<!-- CORRECTION 7: If you have archived using NESSTAR 1 use:"<xsl:value-of select="docDscr/citation/distStmt/contact/@email"/>
												If the dataset is archived under NESSTAR 2, type your email address -->
							<u><xsl:value-of select="docDscr/citation/distStmt/contact/@email"/></u>
							</p>
						</td>
					</tr>
					</table>
					<br/><br/>
					<!--<p align="left" style="font-family:arial"><font size="+2"><b>Abstract</b></font></p>-->
					<table border="0" cellpadding="5" cellspacing="0"><tr>
						<th rowspan="1" valign="top">
							<p align="left" style="font-family:helvetica">
								<font size="+2">
									<b>Abstract</b>
								</font>
							</p>
						</th>
					</tr></table>
					<table border="0" cellpadding="5" cellspacing="0" height="40%" valign="top">
						<tbody>
					<tr>
						<td valign="top">
							<p align="justify" style="font-size:12pt">
								<xsl:value-of select="stdyDscr/stdyInfo/abstract"/>
							</p>
						</td>
					</tr>
					</tbody>
					</table>
					<br/>
					<table border="0" cellpadding="5" cellspacing="0">
						<tbody>
						<tr>
						<th>
							<p align="left" style="font-family:helvetica">
								<font size="+1">
									<b>Keywords</b>
								</font>
							</p>
						</th>
					</tr>
					
					<tr>
						<td >
							<p align="justify" style="font-size:12pt">
								<xsl:value-of select="stdyDscr/stdyInfo/subject/keyword"/><br/><br/><br/>
								
							</p>
						</td>
					</tr>
					<tr>
						<th>
							<p align="left" style="font-family:helvetica">
								<font size="+1"><br/><br/>
									<b>Preferred citation style</b>
								</font>
							</p>
						</th>
					</tr>
					<tr>
						<td>
							<p style="font-size:12pt">
							<!-- CORRECTION 8: Document citation 
								a) If you have archived using NESSTAR 1 use:"<xsl:value-of select="docDscr/citation/distStmt/contact"/>
												If the dataset is archived under NESSTAR 2, use: "xsl:value-of-select="docDscr/citation/rspStmt/AuthEnty"/>
								b) Please enter second author name, if any
								c) Type the serial number of the dataset in Travel Survey Metadata Series
									 -->

								<xsl:value-of select="docDscr/citation/distStmt/contact"/> (2004) <xsl:value-of select="stdyDscr/citation/titlStmt/titl"/>, <i> Travel Survey Metadata Series</i>, <b>1</b>, Institute for Transport Planning and Systems (IVT); ETH Zürich, Zürich. 
							</p>
						</td>
					</tr></tbody>
					</table>
				</body>
		</html>
	</xsl:template>
</xsl:stylesheet>
